extensions = [
		"sphinx.ext.viewcode",
		"sphinx_toolbox",
		]

github_username = "sphinx-toolbox"
github_repository = "sphinx-toolbox"
source_link_target = "GitHub"
project = "Python"
author = "unknown"
